==> core_models-0.2.9.gem: app/models/core_models/base/timespan.rb <==
require 'ice_cube'

# TODO Take advantage of the ice_cube gem
#      Rule.weekly.day(:friday).day_of_month(13).month_of_year(:october).to_yaml ?

module CoreModels
  class Base::Timespan < ApplicationRecord
    #attr_accessible :short_name, :singular_name, :repeating_name
    #attr_accessible :length_in_days
    #attr_accessible :ical_expression

    validates :short_name, :presence => true
    validates :singular_name, :presence => true
    validates :repeating_name, :presence => true

    #---------- Callbacks

    before_save     :before_save_handler

    #----------------------------------------------------------------------------

    def to_s
      ical_expression.nil? ? repeating_name : IceCube::Rule.from_yaml(ical_expression).to_s
    end

    def to_yaml(count = 1)
      case repeating_name
      when 'secondly'
        IceCube::Rule.secondly(count).to_yaml
      when 'minutely'
        IceCube::Rule.minutely(count).to_yaml
      when 'hourly'
        IceCube::Rule.hourly(count).to_yaml
      when 'daily'
        IceCube::Rule.daily(count).to_yaml
      when 'weekly'
        IceCube::Rule.weekly(count).to_yaml
      when 'monthly'
        IceCube::Rule.monthly(count).to_yaml
      when 'annually'
        IceCube::Rule.yearly(count).to_yaml
      else
        ''
      end
    end

    #----------------------------------------------------------------------------

    private

    #---------- Callback handlers

    def before_save_handler
      self.ical_expression = to_yaml
    end
  end
end

==> core_models-0.2.10.gem: app/models/core_models/base/timespan.rb <==
require 'ice_cube'

# TODO: Take advantage of the ice_cube gem
#      Rule.weekly.day(:friday).day_of_month(13).month_of_year(:october).to_yaml ?

module CoreModels
  class Base::Timespan < ApplicationRecord
    # attr_accessible :short_name, :singular_name, :repeating_name
    # attr_accessible :length_in_days
    # attr_accessible :ical_expression

    validates :short_name, presence: true
    validates :singular_name, presence: true
    validates :repeating_name, presence: true

    #---------- Callbacks

    before_save :before_save_handler

    #----------------------------------------------------------------------------

    def to_s
      ical_expression.nil? ? repeating_name : IceCube::Rule.from_yaml(ical_expression).to_s
    end

    def to_yaml(count = 1)
      case repeating_name
      when 'secondly'
        IceCube::Rule.secondly(count).to_yaml
      when 'minutely'
        IceCube::Rule.minutely(count).to_yaml
      when 'hourly'
        IceCube::Rule.hourly(count).to_yaml
      when 'daily'
        IceCube::Rule.daily(count).to_yaml
      when 'weekly'
        IceCube::Rule.weekly(count).to_yaml
      when 'monthly'
        IceCube::Rule.monthly(count).to_yaml
      when 'annually'
        IceCube::Rule.yearly(count).to_yaml
      else
        ''
      end
    end

    #----------------------------------------------------------------------------

    private

    #---------- Callback handlers

    def before_save_handler
      self.ical_expression = to_yaml
    end
  end
end
